@@ -45,6 +45,7 @@ class Test_Api(abstract_test.TestCase):
                                    "datacenterurl": "https://test.com",
                                    "datacenterpath": '/some/path/',
                                    "http_response_headers": ["headers"],
+                                   "acceptcustomeroutput": "2.00",
                                    })
 
         french_config = self.get_config({"locale": "fr_fr",
@@ -109,7 +110,8 @@ class Test_Api(abstract_test.TestCase):
                        {"alias": "test",
                         "libraryversion": self.lib_version,
                         "request": [request1_dict],
-                        "version": "2.00"},
+                        "version": "2.00",
+                        "acceptcustomeroutput": "2.00"},
                        None, None,
                        {"requestreference": request1["requestreference"],
                         "version": "1.00",
@@ -124,7 +126,8 @@ class Test_Api(abstract_test.TestCase):
                        {"alias": "test",
                         "libraryversion": self.lib_version,
                         "request": [request1_dict],
-                        "version": "2.00"},
+                        "version": "2.00",
+                        "acceptcustomeroutput": "2.00"},
                        None, None,
                        {"requestreference": request1["requestreference"],
                         'version': '1.00',
@@ -143,7 +146,8 @@ class Test_Api(abstract_test.TestCase):
                                      "datacenterpath": "/some/other/path/",
                                      "versioninfo": self.version_info,
                                      }],
-                        "version": "2.00"},
+                        "version": "2.00",
+                        "acceptcustomeroutput": "2.00"},
                        None, None,
                        {'requestreference': request2["requestreference"],
                         'version': '1.00',
