@@ -302,6 +302,31 @@ header is returned"
                                       "locale",
                                       locale)
 
+    def test_acceptcustomeroutput(self):
+        config = securetrading.Config()
+        self.assertEqual(None, config.acceptcustomeroutput)
+        tests = [(None, None, ""),
+                 ("1.00", None, ""),
+                 ("2.00", None, ""),
+                 ("TESTING", Exception, "Invalid accept customer output value. \
+Available options: None, 1.00, 2.00"),
+                 ]
+
+        for acceptcustomeroutput, exp_exception, exp_message in tests:
+            if exp_exception is None:
+                config.acceptcustomeroutput = acceptcustomeroutput
+                self.assertEqual(
+                    acceptcustomeroutput,
+                    config.acceptcustomeroutput,
+                )
+            else:
+                six.assertRaisesRegex(self, exp_exception,
+                                      exp_message,
+                                      setattr,
+                                      config,
+                                      "acceptcustomeroutput",
+                                      acceptcustomeroutput)
+
 
 if __name__ == "__main__":
     unittest.main()
